summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/kernel/tqeventloop_unix.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commiteaa7ee2e0bbca40ba3173c4304f81957e8964291 (patch)
tree4f793aa48a5080aedc94ce6e519c3b86708f2b88 /tqtinterface/qt4/src/kernel/tqeventloop_unix.cpp
parent79a9d7a46a20d4a0923bc06fc471fdc2176ef865 (diff)
downloadexperimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.tar.gz
experimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'tqtinterface/qt4/src/kernel/tqeventloop_unix.cpp')
-rw-r--r--tqtinterface/qt4/src/kernel/tqeventloop_unix.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tqtinterface/qt4/src/kernel/tqeventloop_unix.cpp b/tqtinterface/qt4/src/kernel/tqeventloop_unix.cpp
index a865978..53ca943 100644
--- a/tqtinterface/qt4/src/kernel/tqeventloop_unix.cpp
+++ b/tqtinterface/qt4/src/kernel/tqeventloop_unix.cpp
@@ -151,7 +151,7 @@ static inline timeval operator-( const timeval &t1, const timeval &t2 )
// The timerBitVec array is used for keeping track of timer identifiers.
//
-static int allocTimerId() // tqfind avail timer identifier
+static int allocTimerId() // find avail timer identifier
{
int i = timerBitVec->size()-1;
while ( i >= 0 && (*timerBitVec)[i] )
@@ -312,7 +312,7 @@ bool qKillTimer( int id )
id > (int)timerBitVec->size() || !timerBitVec->testBit( id-1 ) )
return FALSE; // not init'd or invalid timer
t = timerList->first();
- while ( t && t->id != id ) // tqfind timer info in list
+ while ( t && t->id != id ) // find timer info in list
t = timerList->next();
if ( t ) { // id found
timerBitVec->clearBit( id-1 ); // set timer inactive
@@ -440,7 +440,7 @@ void TQEventLoop::unregisterSocketNotifier( TQSocketNotifier *notifier )
d->sn_pending_list.removeRef( sn ); // remove from activation list
list->remove(); // remove notifier found above
- if ( d->sn_highest == sockfd ) { // tqfind highest fd
+ if ( d->sn_highest == sockfd ) { // find highest fd
d->sn_highest = -1;
for ( int i=0; i<3; i++ ) {
if ( d->sn_vec[i].list && ! d->sn_vec[i].list->isEmpty() )
@@ -557,7 +557,7 @@ int TQEventLoop::activateTimers()
n_act++;
TQTimerEvent e( t->id );
TQApplication::sendEvent( t->obj, &e ); // send event
- if ( timerList->tqfindRef( begin ) == -1 )
+ if ( timerList->findRef( begin ) == -1 )
begin = 0;
}
return n_act;